#
# spec file for package qore-doc
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           qore-doc
Version:        1.0.10
Release:        bp154.1.63
Summary:        Multithreaded Programming Language
License:        GPL-2.0-or-later OR LGPL-2.1-or-later OR MIT
Group:          Development/Languages/Other
URL:            https://qore.org
Source0:        https://github.com/qorelanguage/qore/archive/refs/tags/release-%{version}.tar.gz#/qore-release-%{version}.tar.gz
# PATCH-FIX-OPENSUSE bmwiedemann boo#1084909
Patch0:         reproducible.patch
BuildRequires:  bison
BuildRequires:  bzip2
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  flex >= 2.5.31
BuildRequires:  gcc-c++ >= 4.8.1
BuildRequires:  gmp-devel
BuildRequires:  graphviz
BuildRequires:  libbz2-devel
BuildRequires:  libtool
BuildRequires:  mpfr-devel
BuildRequires:  openssl-devel
BuildRequires:  pcre-devel
BuildRequires:  pkgconfig
BuildRequires:  qore = %{version}
BuildRequires:  qore-json-module >= 1.8+qore%{version}
BuildRequires:  qore-linenoise-module >= 1.0.0+qore%{version}
BuildRequires:  qore-yaml-module >= 0.7.0+qore%{version}
BuildRequires:  zlib-devel

%description
Qore is a scripting language supporting threading and embedded logic.
It applies a scripting-based approach to interface development and
can also be used as a general purpose language.

%package -n qore-devel-doc
Summary:        Module and library documentation for Qore
Group:          Documentation/HTML

%description -n qore-devel-doc
This package contains the module and library documentation.

Qore is a scripting language supporting threading and embedded logic.
It applies a scripting-based approach to interface development and
can also be used as a general purpose language.

%prep
%autosetup -p1 -n qore-release-%{version}
echo "#define BUILD \"openSUSE\"" > include/qore/intern/git-revision.h

%build
autoreconf -fi
%configure
make html-local

%install

%files
%doc docs/lang/html/*

%files -n qore-devel-doc
%doc docs/library docs/modules

%changelog
* Thu Oct 28 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 1.0.10:
  * Might break backwards compatibility:
  * Some server-side APIs have changed (integration of the Logger
    module in the HttpServer and the HttpServerUtil modules).
  * Implemented the invalid-catch warning when types are required
    by parse options and added to the default warning mask for modules
  * Added support for thread-local global variables
  * Type errors with function and method resolution will report the full
    namespace paths of class and hashdecl types
  * ConnectionProvider module:
  * updated the AbstractConnection::getInfo() method
  * added the AbstractConnection::getExtendedInfo() method
  * DataProvider module:
  * added the limit search option to the DefaultRecordIterator class
  * HttpServer module:
  * allow dynamic handlers to be disabled before being removed
  * integrated the Logger module
  * removed deprecated APIs
  * HttpServerUtil module:
  * integrated the Logger module
  * Logger module:
  * added support for the %%h and %%P patterns for hostname and PID
  * allow file appenders to be reopened
  * enable serialization for LoggerEvent objects as well as for
    them to be submitted directly to Logger objects
  * Added qjar tool for exporting javadoc
  * Many bug fixes
  * Full release notes:
    https://docs.qore.org/qore-1.0.10/lang/html/release_notes.html
- Add fix-module-linker-flags.patch fixing gh#4335
* Sat Jun 12 2021 Jan Engelhardt <jengelh@inai.de>
- Trim marketing wording from description.
* Tue Jun  8 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 0.9.15
  * DataProvider: Fixed a bug where the data type was not supported
    correctly as a data provider type
  * Fixed a potential crash when raising a large number of exceptions
  * Fixed a potential deadlock loading user modules with complex
    initialization code
  * Fixed a bug where SSL errors were not properly cleared before
    I/O operations in all cases
  * Fixed a bug where empty binary values could not be deserialized
  * Fixed handling Qore program destruction in a foreign thread in
    a binary module that could cause a crash
- Fixed abi Provides generation
* Wed May 19 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 0.9.14
  * OracleSqlUtil module and SqlUtil module: fixed various SQL
    generation issues
  * Swagger module: fixed a bug where unknown string format types
    were not ignored but instead caused an exception to be thrown
  * Util module: fixed a bug in parse_memory_size()
  * Full changes:
    https://docs.qore.org/qore-0.9.14/lang/html/release_notes.html
* Wed Apr 14 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 0.9.13
  * Fixes CVE-2020-13615
  * Added saprest tool (a SAP rest client)
  * Bug fixes and improvements for
  * CsvUtil
  * DataProvider
  * FixedLengthUtil
  * HttpServer nad HttpServerUtil
  * ServiceNowRestDataProvider
  * WebUtil
  * RestClient: additional fixes to REST path handling with schema
    validators with a base path
  * New Modules in Qore:
  * ServiceNowRestClient: provides APIs for communicating with
    the ServiceNow REST API
  * ServiceNowRestDataProvider: Provides a data provider API
    for the ServiceNow REST API
  * https://docs.qore.org/qore-0.9.13/lang/html/release_notes.html
- ABI breaks with 0.9.0 update, removed outdated API and updated
  qore-module.prov
- Refreshed reproducible.patch
- Drop unused qore-libtool-2.4.6.patch
- Split -doc package, building the documentation requires the
  yaml module, so this would create a dependency circle
* Mon Aug  5 2019 Dominique Leuenberger <dimstar@opensuse.org>
- Make the qore-module-api-* provides more fail prove: store the
  provides list in qore-module.prov. During build, this file is
  auto-generated and compared against the package provided one to
  ensure the list is correct.
* Thu Jul 12 2018 bwiedemann@suse.com
- Add reproducible.patch to not include build hostname in package
  to make build reproducible (boo#1084909)
* Thu Oct 12 2017 jengelh@inai.de
- Rework scriptlets for ldconfig. Adjust RPM groups.
  Avoid double-shipping of files. Use %%configure.
* Fri Sep 29 2017 petr@yarpen.cz
- updated to 0.8.13
- Input/Output stream APIs
- Vastly improved type system with complex type support
  Improved operators; list, string, binary slice operators,
  the ".." range operator, improved new, cast<>, and
  instanceof operators, lazy evaluation of functional and
  list operators, more
- Improved encryption support including AES encryption,
  encryption/decryption streams, support for AAD and MACs
  Improved HTTPS and SSL security support with addition
  X.509 certificate support including automatic certificate
  verification in client and server contexts
- Universal connection API
- Support for binding output placeholder buffers for result
  sets that return an SQLStatement object for more efficient
  piecewise processing of DB stored procedure/function calls
  that return very large result sets
- Strong encapsulation support (ex: private:internal)
- Deterministic garbage collection performance improvements
  with large cycles
- Debugging support and APIs including remote network debugging
- Language Server Protocol support for Qore in the new astparser
  module for rich language support in IDEs such as the Visual
  studio Code Qore Extension
- much more
- rpm: /usr/bin user programs are part of qore-misc-tools package
  now as it was suggested by advanced packagers on IRC
- rpm: updated qore-libtool-2.4.6.patch for new release
* Thu Sep  8 2016 petr@yarpen.cz
- updated to 0.8.12.1
- removed un-applicable patches: configure.patch
* Fri Jun 12 2015 dimstar@opensuse.org
- Add qore-libtool-2.4.6.patch: Remove imported Libtool 2.4.2
  macros from acinclude.m4: this is a terrible hack by upstream to
  not forcibly depend on libtool >= 2.4.2, which has a very bad
  side effect now with libtool 2.4.6 available: the macros conflict
  due the internal API changes inside libtool.
* Sun Jul 13 2014 schwab@linux-m68k.org
- configure.patch: don't use -m32/-m64
* Fri Jun 20 2014 petr@yarpen.cz
- updated to 0.8.11
* Fri Dec 14 2012 petr@yarpen.cz
- spec file reformatted to fit OBS rules
* Thu Nov  8 2012 david@qore.org
- updated to 0.8.6.2
* Fri Oct 26 2012 david@qore.org
- updated to 0.8.6.1
* Sat Sep  1 2012 david@qore.org
- updated to 0.8.6
* Tue May 22 2012 david@qore.org
- updated to 0.8.5
* Mon May 21 2012 david@qore.org
- updated for new doxygen-based documentation, added devel-doc pkg
  for API docs
- updated package descriptions
* Wed Oct 19 2011 david@qore.org
- updated to 0.8.4
* Thu Oct  6 2011 petr.vanek@qoretechnologies.com
- pkg-config
* Sat Mar  5 2011 david@qore.org
- updated to 0.8.3
* Sat Dec 25 2010 david@qore.org
- updated to 0.8.2
* Mon Jun 14 2010 david@qore.org
- updated to 0.8.1
* Tue Nov 17 2009 david_nichols@users.sourceforge.net
- updated to 0.8.0
* Thu Nov  5 2009 david_nichols@users.sourceforge.net
- updated to 0.7.7
* Sun Jul 12 2009 david_nichols@users.sourceforge.net
- updated to 0.7.6
* Sun Jun 21 2009 david_nichols@users.sourceforge.net
- updated to 0.7.5
* Tue Mar  3 2009 david_nichols@users.sourceforge.net
- updated to 0.7.4
* Tue Dec  2 2008 david_nichols@users.sourceforge.net
- updated to 0.7.3
* Tue Nov 25 2008 david_nichols@users.sourceforge.net
- made libqore* the default name for lib package, removed la file
* Sat Nov 22 2008 david_nichols@users.sourceforge.net
- updated to 0.7.2
* Sun Oct 12 2008 david_nichols@users.sourceforge.net
- fixed devel pacakges for suse
* Mon Oct  6 2008 david_nichols@users.sourceforge.net
- released 0.7.0
* Wed Sep  3 2008 david_nichols@users.sourceforge.net
- removed all modules as they are now independent projects
* Mon Sep  1 2008 david_nichols@users.sourceforge.net
- fixed dist tag for suse distributions
- updated for new module directory, added qore-module-api-*
  capability
* Sun Jul 13 2008 david_nichols@users.sourceforge.net
- copied improvements from opensuse rpm and updated based
  on rpmlint output
- updated version to 0.7.0
* Fri Jun 13 2008 david_nichols@users.sourceforge.net
- fixed spec file to support more architectures
* Thu Apr 10 2008 david_nichols@users.sourceforge.net
- updated package to 0.6.2.4 and disabled mssql module build due
- to lack of freetds packages in the build service :-(
* Sun Oct 15 2006 mrueckert@suse.de
- added --enable-64bit to build properly on 64bit biarch
* Sun Oct 15 2006 mrueckert@suse.de
- initial package of 0.5.3
